@@ -1,9 +1,12 @@
+"""
+jmespath search data
+https://github.com/jmespath/jmespath.py
+"""
 from jmespath import search
 
 
 def jmespath(data, expression, options=None):
     """
-    jmespath search data
-    https://github.com/jmespath/jmespath.py
+    search jmespath data
     """
     return search(expression, data, options)
