@@ -2,6 +2,7 @@
 https://github.com/SergeyPirogov/webdriver_manager
 """
 import os
+from typing import Optional
 
 from webdriver_manager.core.download_manager import DownloadManager
 from webdriver_manager.core.manager import DriverManager
@@ -12,15 +13,15 @@ from webdriver_manager.drivers.chrome import ChromeDriver
 class ChromeDriverManager(DriverManager):
     def __init__(
             self,
-            version: str = None,
-            os_type: str = None,
-            path: str = None,
+            version: Optional[str] = None,
+            os_type: Optional[str] = None,
+            path: Optional[str] = None,
             name: str = "chromedriver",
             url: str = "https://registry.npmmirror.com/-/binary/chromedriver",
             latest_release_url: str = "https://registry.npmmirror.com/-/binary/chromedriver/LATEST_RELEASE",
             chrome_type: str = ChromeType.GOOGLE,
             cache_valid_range: int = 1,
-            download_manager: DownloadManager = None,
+            download_manager: Optional[DownloadManager] = None,
     ):
         super().__init__(
             path,
